# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2
from . import communities_pb2 as communities__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admin.proto',
  package='org.couchers.admin',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0b\x61\x64min.proto\x12\x12org.couchers.admin\x1a\x11\x61nnotations.proto\x1a\x11\x63ommunities.proto\"\x83\x01\n\x0bUserDetails\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12\x11\n\tbirthdate\x18\x07 \x01(\t\x12\x0e\n\x06\x62\x61nned\x18\x05 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\"!\n\x11GetUserDetailsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x13\n\x11GetUserDetailsRes\"3\n\x13\x43hangeUserGenderReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06gender\x18\x02 \x01(\t\"9\n\x16\x43hangeUserBirthdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tbirthdate\x18\x02 \x01(\t\"\x1a\n\nBanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1d\n\rDeleteUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1f\n\x0f\x43reateApiKeyReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x11\n\x0f\x43reateApiKeyRes\"\x81\x01\n\x12\x43reateCommunityReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x11\n\tadmin_ids\x18\x05 \x03(\x03\x12\x0f\n\x07geojson\x18\x06 \x01(\t2\x93\x05\n\x05\x41\x64min\x12Z\n\x0eGetUserDetails\x12%.org.couchers.admin.GetUserDetailsReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12^\n\x10\x43hangeUserGender\x12\'.org.couchers.admin.ChangeUserGenderReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x64\n\x13\x43hangeUserBirthdate\x12*.org.couchers.admin.ChangeUserBirthdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12L\n\x07\x42\x61nUser\x12\x1e.org.couchers.admin.BanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12R\n\nDeleteUser\x12!.org.couchers.admin.DeleteUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12Z\n\x0c\x43reateApiKey\x12#.org.couchers.admin.CreateApiKeyReq\x1a#.org.couchers.admin.CreateApiKeyRes\"\x00\x12\x64\n\x0f\x43reateCommunity\x12&.org.couchers.admin.CreateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3'
  ,
  dependencies=[annotations__pb2.DESCRIPTOR,communities__pb2.DESCRIPTOR,])




_USERDETAILS = _descriptor.Descriptor(
  name='UserDetails',
  full_name='org.couchers.admin.UserDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.admin.UserDetails.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.admin.UserDetails.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='org.couchers.admin.UserDetails.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='org.couchers.admin.UserDetails.gender', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='birthdate', full_name='org.couchers.admin.UserDetails.birthdate', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='banned', full_name='org.couchers.admin.UserDetails.banned', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='org.couchers.admin.UserDetails.deleted', index=6,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=205,
)


_GETUSERDETAILSREQ = _descriptor.Descriptor(
  name='GetUserDetailsReq',
  full_name='org.couchers.admin.GetUserDetailsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.GetUserDetailsReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=207,
  serialized_end=240,
)


_GETUSERDETAILSRES = _descriptor.Descriptor(
  name='GetUserDetailsRes',
  full_name='org.couchers.admin.GetUserDetailsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=261,
)


_CHANGEUSERGENDERREQ = _descriptor.Descriptor(
  name='ChangeUserGenderReq',
  full_name='org.couchers.admin.ChangeUserGenderReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.ChangeUserGenderReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='org.couchers.admin.ChangeUserGenderReq.gender', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=314,
)


_CHANGEUSERBIRTHDATEREQ = _descriptor.Descriptor(
  name='ChangeUserBirthdateReq',
  full_name='org.couchers.admin.ChangeUserBirthdateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.ChangeUserBirthdateReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='birthdate', full_name='org.couchers.admin.ChangeUserBirthdateReq.birthdate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=373,
)


_BANUSERREQ = _descriptor.Descriptor(
  name='BanUserReq',
  full_name='org.couchers.admin.BanUserReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.BanUserReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=401,
)


_DELETEUSERREQ = _descriptor.Descriptor(
  name='DeleteUserReq',
  full_name='org.couchers.admin.DeleteUserReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.DeleteUserReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=432,
)


_CREATEAPIKEYREQ = _descriptor.Descriptor(
  name='CreateApiKeyReq',
  full_name='org.couchers.admin.CreateApiKeyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.CreateApiKeyReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=465,
)


_CREATEAPIKEYRES = _descriptor.Descriptor(
  name='CreateApiKeyRes',
  full_name='org.couchers.admin.CreateApiKeyRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=484,
)


_CREATECOMMUNITYREQ = _descriptor.Descriptor(
  name='CreateCommunityReq',
  full_name='org.couchers.admin.CreateCommunityReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.admin.CreateCommunityReq.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.admin.CreateCommunityReq.slug', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.admin.CreateCommunityReq.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_node_id', full_name='org.couchers.admin.CreateCommunityReq.parent_node_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_ids', full_name='org.couchers.admin.CreateCommunityReq.admin_ids', index=4,
      number=5, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geojson', full_name='org.couchers.admin.CreateCommunityReq.geojson', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=487,
  serialized_end=616,
)

DESCRIPTOR.message_types_by_name['UserDetails'] = _USERDETAILS
DESCRIPTOR.message_types_by_name['GetUserDetailsReq'] = _GETUSERDETAILSREQ
DESCRIPTOR.message_types_by_name['GetUserDetailsRes'] = _GETUSERDETAILSRES
DESCRIPTOR.message_types_by_name['ChangeUserGenderReq'] = _CHANGEUSERGENDERREQ
DESCRIPTOR.message_types_by_name['ChangeUserBirthdateReq'] = _CHANGEUSERBIRTHDATEREQ
DESCRIPTOR.message_types_by_name['BanUserReq'] = _BANUSERREQ
DESCRIPTOR.message_types_by_name['DeleteUserReq'] = _DELETEUSERREQ
DESCRIPTOR.message_types_by_name['CreateApiKeyReq'] = _CREATEAPIKEYREQ
DESCRIPTOR.message_types_by_name['CreateApiKeyRes'] = _CREATEAPIKEYRES
DESCRIPTOR.message_types_by_name['CreateCommunityReq'] = _CREATECOMMUNITYREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserDetails = _reflection.GeneratedProtocolMessageType('UserDetails', (_message.Message,), {
  'DESCRIPTOR' : _USERDETAILS,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.UserDetails)
  })
_sym_db.RegisterMessage(UserDetails)

GetUserDetailsReq = _reflection.GeneratedProtocolMessageType('GetUserDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERDETAILSREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.GetUserDetailsReq)
  })
_sym_db.RegisterMessage(GetUserDetailsReq)

GetUserDetailsRes = _reflection.GeneratedProtocolMessageType('GetUserDetailsRes', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERDETAILSRES,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.GetUserDetailsRes)
  })
_sym_db.RegisterMessage(GetUserDetailsRes)

ChangeUserGenderReq = _reflection.GeneratedProtocolMessageType('ChangeUserGenderReq', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEUSERGENDERREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.ChangeUserGenderReq)
  })
_sym_db.RegisterMessage(ChangeUserGenderReq)

ChangeUserBirthdateReq = _reflection.GeneratedProtocolMessageType('ChangeUserBirthdateReq', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEUSERBIRTHDATEREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.ChangeUserBirthdateReq)
  })
_sym_db.RegisterMessage(ChangeUserBirthdateReq)

BanUserReq = _reflection.GeneratedProtocolMessageType('BanUserReq', (_message.Message,), {
  'DESCRIPTOR' : _BANUSERREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.BanUserReq)
  })
_sym_db.RegisterMessage(BanUserReq)

DeleteUserReq = _reflection.GeneratedProtocolMessageType('DeleteUserReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.DeleteUserReq)
  })
_sym_db.RegisterMessage(DeleteUserReq)

CreateApiKeyReq = _reflection.GeneratedProtocolMessageType('CreateApiKeyReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPIKEYREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.CreateApiKeyReq)
  })
_sym_db.RegisterMessage(CreateApiKeyReq)

CreateApiKeyRes = _reflection.GeneratedProtocolMessageType('CreateApiKeyRes', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPIKEYRES,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.CreateApiKeyRes)
  })
_sym_db.RegisterMessage(CreateApiKeyRes)

CreateCommunityReq = _reflection.GeneratedProtocolMessageType('CreateCommunityReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMMUNITYREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.CreateCommunityReq)
  })
_sym_db.RegisterMessage(CreateCommunityReq)



_ADMIN = _descriptor.ServiceDescriptor(
  name='Admin',
  full_name='org.couchers.admin.Admin',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\004',
  create_key=_descriptor._internal_create_key,
  serialized_start=619,
  serialized_end=1278,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetUserDetails',
    full_name='org.couchers.admin.Admin.GetUserDetails',
    index=0,
    containing_service=None,
    input_type=_GETUSERDETAILSREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeUserGender',
    full_name='org.couchers.admin.Admin.ChangeUserGender',
    index=1,
    containing_service=None,
    input_type=_CHANGEUSERGENDERREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeUserBirthdate',
    full_name='org.couchers.admin.Admin.ChangeUserBirthdate',
    index=2,
    containing_service=None,
    input_type=_CHANGEUSERBIRTHDATEREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BanUser',
    full_name='org.couchers.admin.Admin.BanUser',
    index=3,
    containing_service=None,
    input_type=_BANUSERREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUser',
    full_name='org.couchers.admin.Admin.DeleteUser',
    index=4,
    containing_service=None,
    input_type=_DELETEUSERREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateApiKey',
    full_name='org.couchers.admin.Admin.CreateApiKey',
    index=5,
    containing_service=None,
    input_type=_CREATEAPIKEYREQ,
    output_type=_CREATEAPIKEYRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCommunity',
    full_name='org.couchers.admin.Admin.CreateCommunity',
    index=6,
    containing_service=None,
    input_type=_CREATECOMMUNITYREQ,
    output_type=communities__pb2._COMMUNITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMIN)

DESCRIPTOR.services_by_name['Admin'] = _ADMIN

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bugs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bugs.proto',
  package='org.couchers.bugs',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nbugs.proto\x12\x11org.couchers.bugs\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"\x1e\n\x0bVersionInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\"\x81\x01\n\x0cReportBugReq\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07results\x18\x04 \x01(\t\x12\x18\n\x10\x66rontend_version\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0c\n\x04page\x18\x07 \x01(\t\"/\n\x0cReportBugRes\x12\x0e\n\x06\x62ug_id\x18\x02 \x01(\t\x12\x0f\n\x07\x62ug_url\x18\x03 \x01(\t2\xb2\x01\n\x04\x42ugs\x12S\n\x07Version\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.bugs.VersionInfo\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/version\x12O\n\tReportBug\x12\x1f.org.couchers.bugs.ReportBugReq\x1a\x1f.org.couchers.bugs.ReportBugRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])




_VERSIONINFO = _descriptor.Descriptor(
  name='VersionInfo',
  full_name='org.couchers.bugs.VersionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='org.couchers.bugs.VersionInfo.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=141,
)


_REPORTBUGREQ = _descriptor.Descriptor(
  name='ReportBugReq',
  full_name='org.couchers.bugs.ReportBugReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='org.couchers.bugs.ReportBugReq.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.bugs.ReportBugReq.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='results', full_name='org.couchers.bugs.ReportBugReq.results', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frontend_version', full_name='org.couchers.bugs.ReportBugReq.frontend_version', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='org.couchers.bugs.ReportBugReq.user_agent', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page', full_name='org.couchers.bugs.ReportBugReq.page', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=273,
)


_REPORTBUGRES = _descriptor.Descriptor(
  name='ReportBugRes',
  full_name='org.couchers.bugs.ReportBugRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bug_id', full_name='org.couchers.bugs.ReportBugRes.bug_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bug_url', full_name='org.couchers.bugs.ReportBugRes.bug_url', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=322,
)

DESCRIPTOR.message_types_by_name['VersionInfo'] = _VERSIONINFO
DESCRIPTOR.message_types_by_name['ReportBugReq'] = _REPORTBUGREQ
DESCRIPTOR.message_types_by_name['ReportBugRes'] = _REPORTBUGRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VersionInfo = _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONINFO,
  '__module__' : 'bugs_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.bugs.VersionInfo)
  })
_sym_db.RegisterMessage(VersionInfo)

ReportBugReq = _reflection.GeneratedProtocolMessageType('ReportBugReq', (_message.Message,), {
  'DESCRIPTOR' : _REPORTBUGREQ,
  '__module__' : 'bugs_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.bugs.ReportBugReq)
  })
_sym_db.RegisterMessage(ReportBugReq)

ReportBugRes = _reflection.GeneratedProtocolMessageType('ReportBugRes', (_message.Message,), {
  'DESCRIPTOR' : _REPORTBUGRES,
  '__module__' : 'bugs_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.bugs.ReportBugRes)
  })
_sym_db.RegisterMessage(ReportBugRes)



_BUGS = _descriptor.ServiceDescriptor(
  name='Bugs',
  full_name='org.couchers.bugs.Bugs',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\001',
  create_key=_descriptor._internal_create_key,
  serialized_start=325,
  serialized_end=503,
  methods=[
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='org.couchers.bugs.Bugs.Version',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_VERSIONINFO,
    serialized_options=b'\202\323\344\223\002\n\022\010/version',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReportBug',
    full_name='org.couchers.bugs.Bugs.ReportBug',
    index=1,
    containing_service=None,
    input_type=_REPORTBUGREQ,
    output_type=_REPORTBUGRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BUGS)

DESCRIPTOR.services_by_name['Bugs'] = _BUGS

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gis.proto',
  package='org.couchers.json',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tgis.proto\x12\x11org.couchers.json\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto2\xe3\x02\n\x03GIS\x12P\n\x08GetUsers\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/geojson/users\x12\\\n\x0eGetCommunities\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/geojson/communities\x12R\n\tGetPlaces\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/geojson/places\x12R\n\tGetGuides\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/geojson/guides\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_httpbody__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_GIS = _descriptor.ServiceDescriptor(
  name='GIS',
  full_name='org.couchers.json.GIS',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=138,
  serialized_end=493,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetUsers',
    full_name='org.couchers.json.GIS.GetUsers',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\202\323\344\223\002\020\022\016/geojson/users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommunities',
    full_name='org.couchers.json.GIS.GetCommunities',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\202\323\344\223\002\026\022\024/geojson/communities',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPlaces',
    full_name='org.couchers.json.GIS.GetPlaces',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\202\323\344\223\002\021\022\017/geojson/places',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGuides',
    full_name='org.couchers.json.GIS.GetGuides',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\202\323\344\223\002\021\022\017/geojson/guides',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GIS)

DESCRIPTOR.services_by_name['GIS'] = _GIS

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2
from . import communities_pb2 as communities__pb2
from . import events_pb2 as events__pb2
from . import groups_pb2 as groups__pb2
from . import pages_pb2 as pages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='search.proto',
  package='org.couchers.api.search',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0csearch.proto\x12\x17org.couchers.api.search\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\x1a\x11\x63ommunities.proto\x1a\x0c\x65vents.proto\x1a\x0cgroups.proto\x1a\x0bpages.proto\"0\n\x04\x41rea\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\x12\x0e\n\x06radius\x18\x03 \x01(\x01\"\xe9\x01\n\tSearchReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x15\n\rinclude_users\x18\x04 \x01(\x08\x12\x1b\n\x13include_communities\x18\x05 \x01(\x08\x12\x16\n\x0einclude_groups\x18\x06 \x01(\x08\x12\x16\n\x0einclude_places\x18\x07 \x01(\x08\x12\x16\n\x0einclude_guides\x18\x08 \x01(\x08\x12\x16\n\x0einclude_events\x18\n \x01(\x08\x12\x12\n\ntitle_only\x18\r \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"\xdc\x02\n\x06Result\x12\x0c\n\x04rank\x18\x01 \x01(\x01\x12\x0f\n\x07snippet\x18\x02 \x01(\t\x12+\n\x04user\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.UserH\x00\x12<\n\tcommunity\x18\x04 \x01(\x0b\x32\'.org.couchers.api.communities.CommunityH\x00\x12/\n\x05group\x18\x05 \x01(\x0b\x32\x1e.org.couchers.api.groups.GroupH\x00\x12-\n\x05place\x18\x06 \x01(\x0b\x32\x1c.org.couchers.api.pages.PageH\x00\x12-\n\x05guide\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.PageH\x00\x12/\n\x05\x65vent\x18\x08 \x01(\x0b\x32\x1e.org.couchers.api.events.EventH\x00\x42\x08\n\x06result\"V\n\tSearchRes\x12\x30\n\x07results\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.search.Result\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x90\n\n\rUserSearchReq\x12+\n\x05query\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x17\n\x0fquery_name_only\x18\x1e \x01(\x08\x12/\n\x0blast_active\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x0esearch_in_area\x18\x1c \x01(\x0b\x32\x1d.org.couchers.api.search.AreaH\x00\x12 \n\x16search_in_community_id\x18\x1d \x01(\x03H\x00\x12\x43\n\x15hosting_status_filter\x18\x05 \x03(\x0e\x32$.org.couchers.api.core.HostingStatus\x12G\n\x17smoking_location_filter\x18\x06 \x03(\x0e\x32&.org.couchers.api.core.SmokingLocation\x12O\n\x1bsleeping_arrangement_filter\x18\x07 \x03(\x0e\x32*.org.couchers.api.core.SleepingArrangement\x12\x45\n\x16parking_details_filter\x18\x08 \x03(\x0e\x32%.org.couchers.api.core.ParkingDetails\x12,\n\x06gender\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06guests\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x14only_with_references\x18\x0c \x01(\x08\x12/\n\x0blast_minute\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_pets\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_pets\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_kids\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_kids\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0ehas_housemates\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15wheelchair_accessible\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0esmokes_at_home\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x64rinking_allowed\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x64rinks_at_home\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07parking\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\ncamping_ok\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\tB\x0b\n\tsearch_in\"Z\n\rUserSearchRes\x12\x30\n\x07results\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.search.Result\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc2\x01\n\x06Search\x12R\n\x06Search\x12\".org.couchers.api.search.SearchReq\x1a\".org.couchers.api.search.SearchRes\"\x00\x12^\n\nUserSearch\x12&.org.couchers.api.search.UserSearchReq\x1a&.org.couchers.api.search.UserSearchRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,api__pb2.DESCRIPTOR,communities__pb2.DESCRIPTOR,events__pb2.DESCRIPTOR,groups__pb2.DESCRIPTOR,pages__pb2.DESCRIPTOR,])




_AREA = _descriptor.Descriptor(
  name='Area',
  full_name='org.couchers.api.search.Area',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.api.search.Area.lat', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.api.search.Area.lng', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='org.couchers.api.search.Area.radius', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=244,
)


_SEARCHREQ = _descriptor.Descriptor(
  name='SearchReq',
  full_name='org.couchers.api.search.SearchReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='org.couchers.api.search.SearchReq.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_users', full_name='org.couchers.api.search.SearchReq.include_users', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_communities', full_name='org.couchers.api.search.SearchReq.include_communities', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_groups', full_name='org.couchers.api.search.SearchReq.include_groups', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_places', full_name='org.couchers.api.search.SearchReq.include_places', index=4,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_guides', full_name='org.couchers.api.search.SearchReq.include_guides', index=5,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_events', full_name='org.couchers.api.search.SearchReq.include_events', index=6,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title_only', full_name='org.couchers.api.search.SearchReq.title_only', index=7,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.search.SearchReq.page_size', index=8,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.search.SearchReq.page_token', index=9,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=480,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='org.couchers.api.search.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rank', full_name='org.couchers.api.search.Result.rank', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snippet', full_name='org.couchers.api.search.Result.snippet', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.api.search.Result.user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='community', full_name='org.couchers.api.search.Result.community', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='org.couchers.api.search.Result.group', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='place', full_name='org.couchers.api.search.Result.place', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guide', full_name='org.couchers.api.search.Result.guide', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event', full_name='org.couchers.api.search.Result.event', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='org.couchers.api.search.Result.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=483,
  serialized_end=831,
)


_SEARCHRES = _descriptor.Descriptor(
  name='SearchRes',
  full_name='org.couchers.api.search.SearchRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='org.couchers.api.search.SearchRes.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.search.SearchRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=919,
)


_USERSEARCHREQ = _descriptor.Descriptor(
  name='UserSearchReq',
  full_name='org.couchers.api.search.UserSearchReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='org.couchers.api.search.UserSearchReq.query', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_name_only', full_name='org.couchers.api.search.UserSearchReq.query_name_only', index=1,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_active', full_name='org.couchers.api.search.UserSearchReq.last_active', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_in_area', full_name='org.couchers.api.search.UserSearchReq.search_in_area', index=3,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_in_community_id', full_name='org.couchers.api.search.UserSearchReq.search_in_community_id', index=4,
      number=29, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosting_status_filter', full_name='org.couchers.api.search.UserSearchReq.hosting_status_filter', index=5,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smoking_location_filter', full_name='org.couchers.api.search.UserSearchReq.smoking_location_filter', index=6,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sleeping_arrangement_filter', full_name='org.couchers.api.search.UserSearchReq.sleeping_arrangement_filter', index=7,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_details_filter', full_name='org.couchers.api.search.UserSearchReq.parking_details_filter', index=8,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='org.couchers.api.search.UserSearchReq.gender', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guests', full_name='org.couchers.api.search.UserSearchReq.guests', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_with_references', full_name='org.couchers.api.search.UserSearchReq.only_with_references', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_minute', full_name='org.couchers.api.search.UserSearchReq.last_minute', index=12,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_pets', full_name='org.couchers.api.search.UserSearchReq.has_pets', index=13,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepts_pets', full_name='org.couchers.api.search.UserSearchReq.accepts_pets', index=14,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_kids', full_name='org.couchers.api.search.UserSearchReq.has_kids', index=15,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepts_kids', full_name='org.couchers.api.search.UserSearchReq.accepts_kids', index=16,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_housemates', full_name='org.couchers.api.search.UserSearchReq.has_housemates', index=17,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelchair_accessible', full_name='org.couchers.api.search.UserSearchReq.wheelchair_accessible', index=18,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smokes_at_home', full_name='org.couchers.api.search.UserSearchReq.smokes_at_home', index=19,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drinking_allowed', full_name='org.couchers.api.search.UserSearchReq.drinking_allowed', index=20,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drinks_at_home', full_name='org.couchers.api.search.UserSearchReq.drinks_at_home', index=21,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking', full_name='org.couchers.api.search.UserSearchReq.parking', index=22,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camping_ok', full_name='org.couchers.api.search.UserSearchReq.camping_ok', index=23,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.search.UserSearchReq.page_size', index=24,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.search.UserSearchReq.page_token', index=25,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='search_in', full_name='org.couchers.api.search.UserSearchReq.search_in',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=922,
  serialized_end=2218,
)


_USERSEARCHRES = _descriptor.Descriptor(
  name='UserSearchRes',
  full_name='org.couchers.api.search.UserSearchRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='org.couchers.api.search.UserSearchRes.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.search.UserSearchRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2220,
  serialized_end=2310,
)

_RESULT.fields_by_name['user'].message_type = api__pb2._USER
_RESULT.fields_by_name['community'].message_type = communities__pb2._COMMUNITY
_RESULT.fields_by_name['group'].message_type = groups__pb2._GROUP
_RESULT.fields_by_name['place'].message_type = pages__pb2._PAGE
_RESULT.fields_by_name['guide'].message_type = pages__pb2._PAGE
_RESULT.fields_by_name['event'].message_type = events__pb2._EVENT
_RESULT.oneofs_by_name['result'].fields.append(
  _RESULT.fields_by_name['user'])
_RESULT.fields_by_name['user'].containing_oneof = _RESULT.oneofs_by_name['result']
_RESULT.oneofs_by_name['result'].fields.append(
  _RESULT.fields_by_name['community'])
_RESULT.fields_by_name['community'].containing_oneof = _RESULT.oneofs_by_name['result']
_RESULT.oneofs_by_name['result'].fields.append(
  _RESULT.fields_by_name['group'])
_RESULT.fields_by_name['group'].containing_oneof = _RESULT.oneofs_by_name['result']
_RESULT.oneofs_by_name['result'].fields.append(
  _RESULT.fields_by_name['place'])
_RESULT.fields_by_name['place'].containing_oneof = _RESULT.oneofs_by_name['result']
_RESULT.oneofs_by_name['result'].fields.append(
  _RESULT.fields_by_name['guide'])
_RESULT.fields_by_name['guide'].containing_oneof = _RESULT.oneofs_by_name['result']
_RESULT.oneofs_by_name['result'].fields.append(
  _RESULT.fields_by_name['event'])
_RESULT.fields_by_name['event'].containing_oneof = _RESULT.oneofs_by_name['result']
_SEARCHRES.fields_by_name['results'].message_type = _RESULT
_USERSEARCHREQ.fields_by_name['query'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERSEARCHREQ.fields_by_name['last_active'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USERSEARCHREQ.fields_by_name['search_in_area'].message_type = _AREA
_USERSEARCHREQ.fields_by_name['hosting_status_filter'].enum_type = api__pb2._HOSTINGSTATUS
_USERSEARCHREQ.fields_by_name['smoking_location_filter'].enum_type = api__pb2._SMOKINGLOCATION
_USERSEARCHREQ.fields_by_name['sleeping_arrangement_filter'].enum_type = api__pb2._SLEEPINGARRANGEMENT
_USERSEARCHREQ.fields_by_name['parking_details_filter'].enum_type = api__pb2._PARKINGDETAILS
_USERSEARCHREQ.fields_by_name['gender'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERSEARCHREQ.fields_by_name['guests'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_USERSEARCHREQ.fields_by_name['last_minute'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['has_pets'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['accepts_pets'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['has_kids'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['accepts_kids'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['has_housemates'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['wheelchair_accessible'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['smokes_at_home'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['drinking_allowed'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['drinks_at_home'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['parking'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.fields_by_name['camping_ok'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSEARCHREQ.oneofs_by_name['search_in'].fields.append(
  _USERSEARCHREQ.fields_by_name['search_in_area'])
_USERSEARCHREQ.fields_by_name['search_in_area'].containing_oneof = _USERSEARCHREQ.oneofs_by_name['search_in']
_USERSEARCHREQ.oneofs_by_name['search_in'].fields.append(
  _USERSEARCHREQ.fields_by_name['search_in_community_id'])
_USERSEARCHREQ.fields_by_name['search_in_community_id'].containing_oneof = _USERSEARCHREQ.oneofs_by_name['search_in']
_USERSEARCHRES.fields_by_name['results'].message_type = _RESULT
DESCRIPTOR.message_types_by_name['Area'] = _AREA
DESCRIPTOR.message_types_by_name['SearchReq'] = _SEARCHREQ
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.message_types_by_name['SearchRes'] = _SEARCHRES
DESCRIPTOR.message_types_by_name['UserSearchReq'] = _USERSEARCHREQ
DESCRIPTOR.message_types_by_name['UserSearchRes'] = _USERSEARCHRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Area = _reflection.GeneratedProtocolMessageType('Area', (_message.Message,), {
  'DESCRIPTOR' : _AREA,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.search.Area)
  })
_sym_db.RegisterMessage(Area)

SearchReq = _reflection.GeneratedProtocolMessageType('SearchReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREQ,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.search.SearchReq)
  })
_sym_db.RegisterMessage(SearchReq)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.search.Result)
  })
_sym_db.RegisterMessage(Result)

SearchRes = _reflection.GeneratedProtocolMessageType('SearchRes', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHRES,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.search.SearchRes)
  })
_sym_db.RegisterMessage(SearchRes)

UserSearchReq = _reflection.GeneratedProtocolMessageType('UserSearchReq', (_message.Message,), {
  'DESCRIPTOR' : _USERSEARCHREQ,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.search.UserSearchReq)
  })
_sym_db.RegisterMessage(UserSearchReq)

UserSearchRes = _reflection.GeneratedProtocolMessageType('UserSearchRes', (_message.Message,), {
  'DESCRIPTOR' : _USERSEARCHRES,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.search.UserSearchRes)
  })
_sym_db.RegisterMessage(UserSearchRes)



_SEARCH = _descriptor.ServiceDescriptor(
  name='Search',
  full_name='org.couchers.api.search.Search',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=2313,
  serialized_end=2507,
  methods=[
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='org.couchers.api.search.Search.Search',
    index=0,
    containing_service=None,
    input_type=_SEARCHREQ,
    output_type=_SEARCHRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UserSearch',
    full_name='org.couchers.api.search.Search.UserSearch',
    index=1,
    containing_service=None,
    input_type=_USERSEARCHREQ,
    output_type=_USERSEARCHRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SEARCH)

DESCRIPTOR.services_by_name['Search'] = _SEARCH

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import resources_pb2 as resources__pb2


class ResourcesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetTermsOfService = channel.unary_unary(
                '/org.couchers.resources.Resources/GetTermsOfService',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=resources__pb2.GetTermsOfServiceRes.FromString,
                )
        self.GetCommunityGuidelines = channel.unary_unary(
                '/org.couchers.resources.Resources/GetCommunityGuidelines',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=resources__pb2.GetCommunityGuidelinesRes.FromString,
                )
        self.GetRegions = channel.unary_unary(
                '/org.couchers.resources.Resources/GetRegions',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=resources__pb2.GetRegionsRes.FromString,
                )
        self.GetLanguages = channel.unary_unary(
                '/org.couchers.resources.Resources/GetLanguages',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=resources__pb2.GetLanguagesRes.FromString,
                )


class ResourcesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetTermsOfService(self, request, context):
        """This API contains general resources needed by frontends and managed by the backend team

        Returns the latest Terms of Service markdown, to be shown on signup or if jailed due to this
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommunityGuidelines(self, request, context):
        """Returns the latest Community Guidelines, see GetCommunityGuidelinesRes
        Each of the Community Guidelines should be shown under the text "Please agree to our Community Guidelines", and
        each Community Guideline should be shown with its title, the logo, and the guideline content. The user needs to
        tick a checkbox to agree each of the individual Guidelines and the frontend should only say a user agreed to them
        if they agreed to each one individually.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRegions(self, request, context):
        """Returns a list of allowed regions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLanguages(self, request, context):
        """Returns a list of allowed languages. This is a subset of the full ISO639-3 table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ResourcesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetTermsOfService': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTermsOfService,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=resources__pb2.GetTermsOfServiceRes.SerializeToString,
            ),
            'GetCommunityGuidelines': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCommunityGuidelines,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=resources__pb2.GetCommunityGuidelinesRes.SerializeToString,
            ),
            'GetRegions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRegions,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=resources__pb2.GetRegionsRes.SerializeToString,
            ),
            'GetLanguages': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLanguages,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=resources__pb2.GetLanguagesRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.resources.Resources', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Resources(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetTermsOfService(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.resources.Resources/GetTermsOfService',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            resources__pb2.GetTermsOfServiceRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCommunityGuidelines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.resources.Resources/GetCommunityGuidelines',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            resources__pb2.GetCommunityGuidelinesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRegions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.resources.Resources/GetRegions',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            resources__pb2.GetRegionsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLanguages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.resources.Resources/GetLanguages',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            resources__pb2.GetLanguagesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blocking.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blocking.proto',
  package='org.couchers.blocking',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0e\x62locking.proto\x12\x15org.couchers.blocking\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\" \n\x0c\x42lockUserReq\x12\x10\n\x08username\x18\x01 \x01(\t\"\"\n\x0eUnblockUserReq\x12\x10\n\x08username\x18\x01 \x01(\t\"/\n\x12GetBlockedUsersRes\x12\x19\n\x11\x62locked_usernames\x18\x01 \x03(\t2\x80\x02\n\x08\x42locking\x12H\n\tBlockUser\x12#.org.couchers.blocking.BlockUserReq\x1a\x16.google.protobuf.Empty\x12L\n\x0bUnblockUser\x12%.org.couchers.blocking.UnblockUserReq\x1a\x16.google.protobuf.Empty\x12V\n\x0fGetBlockedUsers\x12\x16.google.protobuf.Empty\x1a).org.couchers.blocking.GetBlockedUsersRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])




_BLOCKUSERREQ = _descriptor.Descriptor(
  name='BlockUserReq',
  full_name='org.couchers.blocking.BlockUserReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.blocking.BlockUserReq.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=121,
)


_UNBLOCKUSERREQ = _descriptor.Descriptor(
  name='UnblockUserReq',
  full_name='org.couchers.blocking.UnblockUserReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.blocking.UnblockUserReq.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=157,
)


_GETBLOCKEDUSERSRES = _descriptor.Descriptor(
  name='GetBlockedUsersRes',
  full_name='org.couchers.blocking.GetBlockedUsersRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocked_usernames', full_name='org.couchers.blocking.GetBlockedUsersRes.blocked_usernames', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=206,
)

DESCRIPTOR.message_types_by_name['BlockUserReq'] = _BLOCKUSERREQ
DESCRIPTOR.message_types_by_name['UnblockUserReq'] = _UNBLOCKUSERREQ
DESCRIPTOR.message_types_by_name['GetBlockedUsersRes'] = _GETBLOCKEDUSERSRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockUserReq = _reflection.GeneratedProtocolMessageType('BlockUserReq', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKUSERREQ,
  '__module__' : 'blocking_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.blocking.BlockUserReq)
  })
_sym_db.RegisterMessage(BlockUserReq)

UnblockUserReq = _reflection.GeneratedProtocolMessageType('UnblockUserReq', (_message.Message,), {
  'DESCRIPTOR' : _UNBLOCKUSERREQ,
  '__module__' : 'blocking_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.blocking.UnblockUserReq)
  })
_sym_db.RegisterMessage(UnblockUserReq)

GetBlockedUsersRes = _reflection.GeneratedProtocolMessageType('GetBlockedUsersRes', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKEDUSERSRES,
  '__module__' : 'blocking_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.blocking.GetBlockedUsersRes)
  })
_sym_db.RegisterMessage(GetBlockedUsersRes)



_BLOCKING = _descriptor.ServiceDescriptor(
  name='Blocking',
  full_name='org.couchers.blocking.Blocking',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=209,
  serialized_end=465,
  methods=[
  _descriptor.MethodDescriptor(
    name='BlockUser',
    full_name='org.couchers.blocking.Blocking.BlockUser',
    index=0,
    containing_service=None,
    input_type=_BLOCKUSERREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnblockUser',
    full_name='org.couchers.blocking.Blocking.UnblockUser',
    index=1,
    containing_service=None,
    input_type=_UNBLOCKUSERREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockedUsers',
    full_name='org.couchers.blocking.Blocking.GetBlockedUsers',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETBLOCKEDUSERSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BLOCKING)

DESCRIPTOR.services_by_name['Blocking'] = _BLOCKING

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: threads.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='threads.proto',
  package='org.couchers.api.threads',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rthreads.proto\x12\x18org.couchers.api.threads\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"2\n\x06Thread\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x15\n\rnum_responses\x18\x02 \x01(\x03\"H\n\x0cGetThreadReq\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Y\n\x0cGetThreadRes\x12\x30\n\x07replies\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\x8a\x01\n\x05Reply\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x16\n\x0e\x61uthor_user_id\x18\x03 \x01(\x03\x12\x30\n\x0c\x63reated_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bnum_replies\x18\x05 \x01(\r\"2\n\x0cPostReplyReq\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"!\n\x0cPostReplyRes\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x32\xc9\x01\n\x07Threads\x12[\n\tGetThread\x12&.org.couchers.api.threads.GetThreadReq\x1a&.org.couchers.api.threads.GetThreadRes\x12[\n\tPostReply\x12&.org.couchers.api.threads.PostReplyReq\x1a&.org.couchers.api.threads.PostReplyRes\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])




_THREAD = _descriptor.Descriptor(
  name='Thread',
  full_name='org.couchers.api.threads.Thread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.Thread.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_responses', full_name='org.couchers.api.threads.Thread.num_responses', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=145,
)


_GETTHREADREQ = _descriptor.Descriptor(
  name='GetThreadReq',
  full_name='org.couchers.api.threads.GetThreadReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.GetThreadReq.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.threads.GetThreadReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.threads.GetThreadReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=219,
)


_GETTHREADRES = _descriptor.Descriptor(
  name='GetThreadRes',
  full_name='org.couchers.api.threads.GetThreadRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='replies', full_name='org.couchers.api.threads.GetThreadRes.replies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.threads.GetThreadRes.next_page_token', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=310,
)


_REPLY = _descriptor.Descriptor(
  name='Reply',
  full_name='org.couchers.api.threads.Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.Reply.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.threads.Reply.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author_user_id', full_name='org.couchers.api.threads.Reply.author_user_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_time', full_name='org.couchers.api.threads.Reply.created_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_replies', full_name='org.couchers.api.threads.Reply.num_replies', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=451,
)


_POSTREPLYREQ = _descriptor.Descriptor(
  name='PostReplyReq',
  full_name='org.couchers.api.threads.PostReplyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.PostReplyReq.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.threads.PostReplyReq.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=503,
)


_POSTREPLYRES = _descriptor.Descriptor(
  name='PostReplyRes',
  full_name='org.couchers.api.threads.PostReplyRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.PostReplyRes.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=538,
)

_GETTHREADRES.fields_by_name['replies'].message_type = _REPLY
_REPLY.fields_by_name['created_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Thread'] = _THREAD
DESCRIPTOR.message_types_by_name['GetThreadReq'] = _GETTHREADREQ
DESCRIPTOR.message_types_by_name['GetThreadRes'] = _GETTHREADRES
DESCRIPTOR.message_types_by_name['Reply'] = _REPLY
DESCRIPTOR.message_types_by_name['PostReplyReq'] = _POSTREPLYREQ
DESCRIPTOR.message_types_by_name['PostReplyRes'] = _POSTREPLYRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Thread = _reflection.GeneratedProtocolMessageType('Thread', (_message.Message,), {
  'DESCRIPTOR' : _THREAD,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.Thread)
  })
_sym_db.RegisterMessage(Thread)

GetThreadReq = _reflection.GeneratedProtocolMessageType('GetThreadReq', (_message.Message,), {
  'DESCRIPTOR' : _GETTHREADREQ,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.GetThreadReq)
  })
_sym_db.RegisterMessage(GetThreadReq)

GetThreadRes = _reflection.GeneratedProtocolMessageType('GetThreadRes', (_message.Message,), {
  'DESCRIPTOR' : _GETTHREADRES,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.GetThreadRes)
  })
_sym_db.RegisterMessage(GetThreadRes)

Reply = _reflection.GeneratedProtocolMessageType('Reply', (_message.Message,), {
  'DESCRIPTOR' : _REPLY,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.Reply)
  })
_sym_db.RegisterMessage(Reply)

PostReplyReq = _reflection.GeneratedProtocolMessageType('PostReplyReq', (_message.Message,), {
  'DESCRIPTOR' : _POSTREPLYREQ,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.PostReplyReq)
  })
_sym_db.RegisterMessage(PostReplyReq)

PostReplyRes = _reflection.GeneratedProtocolMessageType('PostReplyRes', (_message.Message,), {
  'DESCRIPTOR' : _POSTREPLYRES,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.PostReplyRes)
  })
_sym_db.RegisterMessage(PostReplyRes)



_THREADS = _descriptor.ServiceDescriptor(
  name='Threads',
  full_name='org.couchers.api.threads.Threads',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=541,
  serialized_end=742,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetThread',
    full_name='org.couchers.api.threads.Threads.GetThread',
    index=0,
    containing_service=None,
    input_type=_GETTHREADREQ,
    output_type=_GETTHREADRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostReply',
    full_name='org.couchers.api.threads.Threads.PostReply',
    index=1,
    containing_service=None,
    input_type=_POSTREPLYREQ,
    output_type=_POSTREPLYRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_THREADS)

DESCRIPTOR.services_by_name['Threads'] = _THREADS

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import events_pb2 as events__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class EventsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateEvent = channel.unary_unary(
                '/org.couchers.api.events.Events/CreateEvent',
                request_serializer=events__pb2.CreateEventReq.SerializeToString,
                response_deserializer=events__pb2.Event.FromString,
                )
        self.ScheduleEvent = channel.unary_unary(
                '/org.couchers.api.events.Events/ScheduleEvent',
                request_serializer=events__pb2.ScheduleEventReq.SerializeToString,
                response_deserializer=events__pb2.Event.FromString,
                )
        self.UpdateEvent = channel.unary_unary(
                '/org.couchers.api.events.Events/UpdateEvent',
                request_serializer=events__pb2.UpdateEventReq.SerializeToString,
                response_deserializer=events__pb2.Event.FromString,
                )
        self.GetEvent = channel.unary_unary(
                '/org.couchers.api.events.Events/GetEvent',
                request_serializer=events__pb2.GetEventReq.SerializeToString,
                response_deserializer=events__pb2.Event.FromString,
                )
        self.ListEventOccurrences = channel.unary_unary(
                '/org.couchers.api.events.Events/ListEventOccurrences',
                request_serializer=events__pb2.ListEventOccurrencesReq.SerializeToString,
                response_deserializer=events__pb2.ListEventOccurrencesRes.FromString,
                )
        self.ListEventAttendees = channel.unary_unary(
                '/org.couchers.api.events.Events/ListEventAttendees',
                request_serializer=events__pb2.ListEventAttendeesReq.SerializeToString,
                response_deserializer=events__pb2.ListEventAttendeesRes.FromString,
                )
        self.ListEventSubscribers = channel.unary_unary(
                '/org.couchers.api.events.Events/ListEventSubscribers',
                request_serializer=events__pb2.ListEventSubscribersReq.SerializeToString,
                response_deserializer=events__pb2.ListEventSubscribersRes.FromString,
                )
        self.ListEventOrganizers = channel.unary_unary(
                '/org.couchers.api.events.Events/ListEventOrganizers',
                request_serializer=events__pb2.ListEventOrganizersReq.SerializeToString,
                response_deserializer=events__pb2.ListEventOrganizersRes.FromString,
                )
        self.TransferEvent = channel.unary_unary(
                '/org.couchers.api.events.Events/TransferEvent',
                request_serializer=events__pb2.TransferEventReq.SerializeToString,
                response_deserializer=events__pb2.Event.FromString,
                )
        self.SetEventSubscription = channel.unary_unary(
                '/org.couchers.api.events.Events/SetEventSubscription',
                request_serializer=events__pb2.SetEventSubscriptionReq.SerializeToString,
                response_deserializer=events__pb2.Event.FromString,
                )
        self.SetEventAttendance = channel.unary_unary(
                '/org.couchers.api.events.Events/SetEventAttendance',
                request_serializer=events__pb2.SetEventAttendanceReq.SerializeToString,
                response_deserializer=events__pb2.Event.FromString,
                )
        self.InviteEventOrganizer = channel.unary_unary(
                '/org.couchers.api.events.Events/InviteEventOrganizer',
                request_serializer=events__pb2.InviteEventOrganizerReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RemoveEventOrganizer = channel.unary_unary(
                '/org.couchers.api.events.Events/RemoveEventOrganizer',
                request_serializer=events__pb2.RemoveEventOrganizerReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListMyEvents = channel.unary_unary(
                '/org.couchers.api.events.Events/ListMyEvents',
                request_serializer=events__pb2.ListMyEventsReq.SerializeToString,
                response_deserializer=events__pb2.ListMyEventsRes.FromString,
                )
        self.ListAllEvents = channel.unary_unary(
                '/org.couchers.api.events.Events/ListAllEvents',
                request_serializer=events__pb2.ListAllEventsReq.SerializeToString,
                response_deserializer=events__pb2.ListAllEventsRes.FromString,
                )


class EventsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateEvent(self, request, context):
        """Creates an event, only one instance, add more with ScheduleEvent
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScheduleEvent(self, request, context):
        """Schedules a new occurrence of an existing event
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEvent(self, request, context):
        """Edit an event
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEvent(self, request, context):
        """Gets an event
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEventOccurrences(self, request, context):
        """List all occurrences of a recurring event
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEventAttendees(self, request, context):
        """Paginated list of event attendees
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEventSubscribers(self, request, context):
        """Paginated list of event subscribers
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEventOrganizers(self, request, context):
        """Paginated list of event organizers
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransferEvent(self, request, context):
        """Transfer an event you own to either a group or a community
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetEventSubscription(self, request, context):
        """Subscribe to get notifications about all occurrences of an event
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetEventAttendance(self, request, context):
        """RSVP/change going status for an occurrence of an event
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InviteEventOrganizer(self, request, context):
        """Invite another user to become an organizer of this event
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveEventOrganizer(self, request, context):
        """Remove yourself as an event organizer
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMyEvents(self, request, context):
        """Lists all subscribed, attending
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAllEvents(self, request, context):
        """Lists all events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEvent,
                    request_deserializer=events__pb2.CreateEventReq.FromString,
                    response_serializer=events__pb2.Event.SerializeToString,
            ),
            'ScheduleEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.ScheduleEvent,
                    request_deserializer=events__pb2.ScheduleEventReq.FromString,
                    response_serializer=events__pb2.Event.SerializeToString,
            ),
            'UpdateEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEvent,
                    request_deserializer=events__pb2.UpdateEventReq.FromString,
                    response_serializer=events__pb2.Event.SerializeToString,
            ),
            'GetEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvent,
                    request_deserializer=events__pb2.GetEventReq.FromString,
                    response_serializer=events__pb2.Event.SerializeToString,
            ),
            'ListEventOccurrences': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEventOccurrences,
                    request_deserializer=events__pb2.ListEventOccurrencesReq.FromString,
                    response_serializer=events__pb2.ListEventOccurrencesRes.SerializeToString,
            ),
            'ListEventAttendees': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEventAttendees,
                    request_deserializer=events__pb2.ListEventAttendeesReq.FromString,
                    response_serializer=events__pb2.ListEventAttendeesRes.SerializeToString,
            ),
            'ListEventSubscribers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEventSubscribers,
                    request_deserializer=events__pb2.ListEventSubscribersReq.FromString,
                    response_serializer=events__pb2.ListEventSubscribersRes.SerializeToString,
            ),
            'ListEventOrganizers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEventOrganizers,
                    request_deserializer=events__pb2.ListEventOrganizersReq.FromString,
                    response_serializer=events__pb2.ListEventOrganizersRes.SerializeToString,
            ),
            'TransferEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.TransferEvent,
                    request_deserializer=events__pb2.TransferEventReq.FromString,
                    response_serializer=events__pb2.Event.SerializeToString,
            ),
            'SetEventSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.SetEventSubscription,
                    request_deserializer=events__pb2.SetEventSubscriptionReq.FromString,
                    response_serializer=events__pb2.Event.SerializeToString,
            ),
            'SetEventAttendance': grpc.unary_unary_rpc_method_handler(
                    servicer.SetEventAttendance,
                    request_deserializer=events__pb2.SetEventAttendanceReq.FromString,
                    response_serializer=events__pb2.Event.SerializeToString,
            ),
            'InviteEventOrganizer': grpc.unary_unary_rpc_method_handler(
                    servicer.InviteEventOrganizer,
                    request_deserializer=events__pb2.InviteEventOrganizerReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RemoveEventOrganizer': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveEventOrganizer,
                    request_deserializer=events__pb2.RemoveEventOrganizerReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListMyEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMyEvents,
                    request_deserializer=events__pb2.ListMyEventsReq.FromString,
                    response_serializer=events__pb2.ListMyEventsRes.SerializeToString,
            ),
            'ListAllEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAllEvents,
                    request_deserializer=events__pb2.ListAllEventsReq.FromString,
                    response_serializer=events__pb2.ListAllEventsRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.events.Events', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Events(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/CreateEvent',
            events__pb2.CreateEventReq.SerializeToString,
            events__pb2.Event.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScheduleEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/ScheduleEvent',
            events__pb2.ScheduleEventReq.SerializeToString,
            events__pb2.Event.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/UpdateEvent',
            events__pb2.UpdateEventReq.SerializeToString,
            events__pb2.Event.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/GetEvent',
            events__pb2.GetEventReq.SerializeToString,
            events__pb2.Event.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEventOccurrences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/ListEventOccurrences',
            events__pb2.ListEventOccurrencesReq.SerializeToString,
            events__pb2.ListEventOccurrencesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEventAttendees(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/ListEventAttendees',
            events__pb2.ListEventAttendeesReq.SerializeToString,
            events__pb2.ListEventAttendeesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEventSubscribers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/ListEventSubscribers',
            events__pb2.ListEventSubscribersReq.SerializeToString,
            events__pb2.ListEventSubscribersRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEventOrganizers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/ListEventOrganizers',
            events__pb2.ListEventOrganizersReq.SerializeToString,
            events__pb2.ListEventOrganizersRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TransferEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/TransferEvent',
            events__pb2.TransferEventReq.SerializeToString,
            events__pb2.Event.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetEventSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/SetEventSubscription',
            events__pb2.SetEventSubscriptionReq.SerializeToString,
            events__pb2.Event.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetEventAttendance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/SetEventAttendance',
            events__pb2.SetEventAttendanceReq.SerializeToString,
            events__pb2.Event.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InviteEventOrganizer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/InviteEventOrganizer',
            events__pb2.InviteEventOrganizerReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveEventOrganizer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/RemoveEventOrganizer',
            events__pb2.RemoveEventOrganizerReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMyEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/ListMyEvents',
            events__pb2.ListMyEventsReq.SerializeToString,
            events__pb2.ListMyEventsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAllEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.events.Events/ListAllEvents',
            events__pb2.ListAllEventsReq.SerializeToString,
            events__pb2.ListAllEventsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
